/** @file wxutils.cpp
*
*  @brief implementation of some little utility functions
*
*  @author T. Modes
*/

/*  This program is free software; you can redistribute it and/or
*  modify it under the terms of the GNU General Public
*  License as published by the Free Software Foundation; either
*  version 2 of the License, or (at your option) any later version.
*
*  This software is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*  General Public License for more details.
*
*  You should have received a copy of the GNU General Public
*  License along with this software. If not, see
*  <http://www.gnu.org/licenses/>.
*
*/

#include "wxutils.h"
#include <wx/translation.h>

WXIMPEX wxString GetFormattedTimeSpan(const wxTimeSpan& timeSpan)
{
    if (timeSpan.IsNull())
    {
        return wxEmptyString;
    };
    if (timeSpan.GetHours() >= 1)
    {
        // longer than 1 h, format hours:minutes
        return timeSpan.Format(_("%H:%M h"));
    }
    else
    {
        // shorter than 1 h
        if (timeSpan.GetSeconds() > 60)
        {
            // format minutes:seconds
            return timeSpan.Format(_("%M:%S min"));
        }
        else
        {
            if (timeSpan.GetSeconds() < 1)
            {
                // shorter then 1 s, don't display anything
                return wxEmptyString;
            }
            else
            {
                // below 1 min, show only seconds
                return timeSpan.Format(_("%S s"));
            }
        }
    }
}
